@@ -4,6 +4,7 @@
 from django.db.models import URLField, SubfieldBase
 
 from slumber.connector.api import _InstanceProxy, get_instance_from_url
+from slumber.connector.dictobject import DictObject
 from slumber.forms import RemoteForeignKeyField
 from slumber.scheme import to_slumber_scheme, from_slumber_scheme
 from slumber.server import get_slumber_services
@@ -34,7 +35,7 @@ class RemoteForeignKey(URLField):
         return super(RemoteForeignKey, self).get_db_prep_value(url, *a, **kw)
 
     def get_prep_value(self, value, *a, **kw):
-        if isinstance(value, basestring):
+        if isinstance(value, basestring) or isinstance(value, DictObject):
             return value
         url = to_slumber_scheme(value._url, get_slumber_services())
         return super(RemoteForeignKey, self).get_prep_value(url, *a, **kw)
